@@ -1160,7 +1160,7 @@ export class DataTabulatorView extends HTMLBoxView {
       }
       columns.push(button_column)
     }
-    if (this.model.container_popup) {
+    if (this.model.container_popup && (this.model.layout !== "fit_data_stretch")) {
       // We insert an empty last column to ensure select editor is rendered in correct position
       // see: https://github.com/holoviz/panel/issues/7295
       columns.push({width: 1, maxWidth: 1, minWidth: 1, resizable: false, cssClass: "empty", sorter: null})
